@@ -1,5 +1,5 @@
 package experimental;
-$experimental::VERSION = '0.011';
+$experimental::VERSION = '0.015';
 use strict;
 use warnings;
 use version ();
@@ -20,6 +20,7 @@ my %features = map { $_ => 1 } $] > 5.015006 ? keys %feature::feature : do {
 my %min_version = (
 	array_base      => '5',
 	autoderef       => '5.14.0',
+	bitwise         => '5.22.0',
 	current_sub     => '5.16.0',
 	evalbytes       => '5.16.0',
 	fc              => '5.16.0',
@@ -27,6 +28,7 @@ my %min_version = (
 	lexical_subs    => '5.18.0',
 	postderef       => '5.20.0',
 	postderef_qq    => '5.20.0',
+	refaliasing     => '5.22.0',
 	regex_sets      => '5.18.0',
 	say             => '5.10.0',
 	smartmatch      => '5.10.0',
@@ -36,6 +38,10 @@ my %min_version = (
 	unicode_eval    => '5.16.0',
 	unicode_strings => '5.12.0',
 );
+my %max_version = (
+	lexical_topic   => '5.23.4',
+);
+
 $_ = version->new($_) for values %min_version;
 
 my %additional = (
@@ -54,11 +60,20 @@ sub _enable {
 		feature->import($pragma);
 		_enable(@{ $additional{$pragma} }) if $additional{$pragma};
 	}
+	elsif ($] >= $max_version{$pragma}) {
+		croak "Experimental feature $pragma has been removed from perl in version $max_version{$pragma}";
+	}
 	elsif (not exists $min_version{$pragma}) {
 		croak "Can't enable unknown feature $pragma";
 	}
-	elsif ($min_version{$pragma} > $]) {
-		croak "Need perl $min_version{$pragma} or later for feature $pragma";
+	elsif ($] < $min_version{$pragma}) {
+		my $stable = $min_version{$pragma};
+		if ($stable->{version}[1] % 2) {
+			$stable = version->new(
+				"5.".($stable->{version}[1]+1).'.0'
+			);
+		}
+		croak "Need perl $stable or later for feature $pragma";
 	}
 }
 
@@ -112,7 +127,7 @@ experimental - Experimental features made easy
 
 =head1 VERSION
 
-version 0.011
+version 0.015
 
 =head1 SYNOPSIS
 
@@ -148,6 +163,7 @@ The supported features, documented further below, are:
 	lexical_topic - allow the use of lexical $_ via "my $_"
 	postderef     - allow the use of postfix dereferencing expressions, including
 	                in interpolating strings
+	refaliasing   - allow aliasing via \$x = \$y
 	regex_sets    - allow extended bracketed character classes in regexps
 	signatures    - allow subroutine signatures (for named arguments)
 	smartmatch    - allow the use of ~~
